Para el que le interese.

--
Dr. Horacio Castellini, Dpto de F'isica, Facultad de Ingenier'ia,
Ciencias Exactas y Agrimensura, Pellegrini 250, 2000 Rosario
Argentina, Usuario Linux Registrado #53602
Correo-e:[EMAIL PROTECTED] ICQ: 52244442




=====================================================
About this e-mail
You are receiving this e-mail because you requested to receive 
information regarding special offers, product upgrades, and other 
updates involving Corel's Linux products. 

If you have received this e-mail in error or wish to remove your name 
from our customer list, please scroll down to the bottom of the 
message to learn how to unsubscribe from this list. 
=====================================================

If you have difficulty reading this e-mail for whatever reason, please 
feel free to read The Cube online by visiting 
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0EkLHKhgspgL

       --------------------------------------------------
                            The Cube
              Corel's Quarterly Linux eNewsletter
                     Issue 2, November 2000
                -------------------------------

In This Issue...

News On the Block
1. KDE League is Formed With Corel as a Founding Member
2. Development on Upcoming Editions of Corel(R) LINUX(R) OS Well Underway
3. LinuxWorld and Fall Comdex's Linux Business Expo Huge Successes for Corel!
4. Partners in Linux ... Corel's Newest Strategic Alliances
5. And the Winner Is ... Recent Awards & Accolades for Corel's Linux Products

Linux.Corel.com
6. FREE Downloads, Tutorials, Tips & Tricks, Training, Updates and More at 
Linux.Corel.com!

What's New and Cool With Linux
7. KDE 2.0: The Next Generation Linux Desktop
        
Getting the Job Done With Linux
8. Setting Up Corel LINUX OS as a Web Server Using Apache
9. Publishing Images to the Web with Corel PHOTO-PAINT(R) for Linux
10. Migrating Your Windows(R) Settings Over to Linux with Corel(R) SmartMove
11. Optimizing Hard Disk Performance Using hdparm

Developer's Corner      
12. Cprof: A Multi-Threaded Performance Profiler

==================
News On the Block
==================
---------------------------------------------------------   
1. KDE League is Formed With Corel as a Founding Member
---------------------------------------------------------
Developers of the K Desktop Environment, the easy-to-use Open Source 
desktop environment, recently announced the formation of the KDE League, 
a group of industry leaders and developers devoted to the promotion, 
distribution and development of KDE. The KDE League's self-described 
goal is to "establish KDE as a desktop standard for PCs, workstations, 
and mobile devices, to promote software development for KDE and to promote 
the use of KDE by enterprises and individuals."

Corel is very proud to be a founding member of the KDE League and will 
provide the new initiative with financial and promotional support. The 
implementation of KDE into Corel LINUX OS allows Corel to create a 
familiar, easy-to-use interface and will continue to play a key role in 
the broader adoption of Linux.

For more information on the KDE League, visit 
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0ErKLsLHnNL

--------------------------------------------------------------------
2. Development on Upcoming Editions of Corel LINUX OS Well Underway
--------------------------------------------------------------------
Corel's Linux development team is hard at work on the next desktop version, 
as well as server and enterprise editions of Corel LINUX OS. Not too many 
secrets have been revealed as of yet, but users can expect future versions 
of Corel LINUX OS to include the latest enhancements to the Linux 
environment, including KDE 2.0, Debian Woody, XFree86 4.0, Kernel 2.4 and 
much more!

Keep an eye out for more information in future issues of The Cube.

-----------------------------------------------------------------------------
3. LinuxWorld and Fall Comdex's Linux Business Expo Huge Successes for Corel!
-----------------------------------------------------------------------------
It was just over a year ago at Fall Comdex's Linux Business Expo that Corel 
unveiled the initial release of Corel LINUX OS. Corel continued to impress 
crowds at the show this November with demonstrations of Corel LINUX OS Second 
Edition, WordPerfect(R) Office 2000 for Linux and CorelDRAW Graphics Suite for 
Linux. Corel also showcased its Linux Professional Services offerings. 

As well, Corel was the talk of LinuxWorld Expo this August with the 
simultaneous launch of Corel LINUX OS Second Edition (the enhanced version of 
the award-winning operating system) and CorelDRAW(R) Graphics Suite for Linux.

A big thanks to everyone who visited the Corel booth at these events. We hope 
you had as much fun learning about our Linux products as we had demonstrating 
them for you. 

For more information on the products and services showcased at these events, 
visit these sites:

-Corel LINUX OS Second Edition: 
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0EJshl
-WordPerfect Office 2000 for Linux: 
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0EPihspgNQ
-CorelDRAW Graphics Suite for Linux: 
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0EKkHPspgNQ
-Corel Linux Professional Services: 
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0EikhlLkO

-----------------------------------------------------------
4. Partners in Linux ... Corel's Newest Strategic Alliances
-----------------------------------------------------------
PCTEL, Inc.: Corel and PCTEL are partnering to bring the industry's first 
Linux-compatible software modem to the market. For more information, visit
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0EiJmLs

Sair Linux, Inc.: Corel is teaming with Sair Linux for Linux and GNU 
training. For more information, visit
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0ElHpk

------------------------------------------------------------------------------
5. And the Winner Is ... Recent Awards & Accolades for Corel's Linux Products
------------------------------------------------------------------------------
Corel LINUX OS deemed "Best of 2000" by Internet Eye -- Read this review to 
find out why the author believes Corel LINUX OS to be "truly the best Linux for 
your desktop". Visit
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0EpgmLkgLmLRL

Corel LINUX OS gets PCWorld.com to proclaim that Linux is "Not Just for 
Geeks Anymore" -- To find out how Corel has makes Linux "a kinder, gentler, 
more-approachable operating system", visit 
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0EiJPhksK

CorelDRAW Graphics Suite for Linux: "It's a polished pair of applications, with 
good documentation and a sense of underlying slickness." -- Read more at
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0EspgNQisHgLm

CNET declares WordPerfect Office 2000 for Linux "a must-have for Linux newbies 
or home users." -- For details, visit
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0EJgLm

To read more reviews of Corel's Linux Products, visit 
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0EkLOpLPl

================
Linux.Corel.com
================
---------------------------------------------------------------------------
6. FREE Downloads, Tutorials, Tips & Tricks, Training, Updates and More at 
Linux.Corel.com!
---------------------------------------------------------------------------
>From step-by-step tutorials, to support and product updates, you can find it 
all for your Corel Linux product at Linux.Corel.com. Visit the site today for 
brand new Tips & Tricks, useful help documents and a collection of practical 
tutorials. You can even get trained at Linux.Corel.com, either by ordering one 
of our new training manuals or by taking advantage of the free Web-based training 
available for Corel LINUX OS.

Users of CorelDRAW Graphics Suite for Linux can download an updated libaps 
package to help the suite run smoothly on different Linux distributions. And, 
of course, Corel's ever-popular free Linux downloads (including Corel LINUX OS, 
Corel WordPerfect 8 for Linux and Corel PHOTO-PAINT for Linux) are always easily 
accessible from the site.

For all this and much more, visit Linux.Corel.com:
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0EJsJhttNgpmR

Quick Tip - Accessing the Root Account When Logged in as a Regular User in 
Corel LINUX OS: 

In Corel LINUX OS, you can access the root account from the Console when logged 
in as a regular user. This feature lets regular users perform system 
administration functions through the root account. 

To access the root account when logged in as a regular user: 

1. Click the Console button on the Panel
2. Type su when you are prompted
3. Press ENTER 
4. Type the root account password if you are prompted. You are prompted only if 
you have already set a password for the root account 
5. Press ENTER 

For more useful Tips & Tricks to help you use Corel's Linux products more 
efficiently, visit
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0EspgNQmpil 

============================
What's New and Cool With Linux
============================
----------------------------------------------
7. KDE 2.0: The Next Generation Linux Desktop
----------------------------------------------
Hundreds of dedicated developers in over 30 countries contributed to the 
October 23 release of KDE 2.0, the new version of the K Desktop Environment's 
modular, Internet-enabled desktop. The new release offers desktop users the 
benefit of standards compliance and is being billed as more intuitive, powerful 
and user-friendly. 

In addition to a slew of usability enhancements making it easier to theme and 
customize, KDE 2.0 features a wide range of new technologies, including a 
full-featured Web browser and file manager (Konqueror), and an integrated 
office suite (KOffice). The new version also includes a set of powerful 
development tools to help with the speedy deployment of high-quality software.

Here's what Rene Schmidt, Corel's Executive Vice-President of Linux Products, 
had to say about KDE 2.0: "Corel has had a long, successful relationship with 
the KDE project, and the release of KDE 2.0 is an important milestone for Linux. 
We believe that our customers will be ecstatic over the improvements and new 
features of this landmark version. The enhancements to the framework provide 
power for the desktop in the simple and elegant fashion that our customers have 
grown to expect."

You can look for KDE 2.0 to be implemented into future versions of Corel LINUX OS. 
For more information on KDE 2.0, visit
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0ErKLV

============================
Getting the Job Done With Linux
============================
----------------------------------------------------------
8. Setting Up Corel LINUX OS as a Web Server Using Apache
----------------------------------------------------------
One of the least talked about yet most impressive features of Corel LINUX OS is 
its ability to be easily set up as an HTTP server using Apache. To read a tutorial 
that walks you through the process of setting up an HTTP server with Apache, 
starting right from the Corel LINUX OS installation process, visit 
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0EPLIlLkOLk

------------------------------------------------------------------
9. Publishing Images to the Web with Corel PHOTO-PAINT for Linux
------------------------------------------------------------------
Whether you're a professional Web designer or just building your own homepage, 
it can be hard to get your head around all the little details involved in creating 
and publishing images to the Internet. But with a little bit of guidance and the 
right tools, the process is surprisingly simple. With Corel PHOTO-PAINT for Linux, 
Web designers can enjoy stellar image quality, compression and export capabilities, 
all on the Linux platform. Follow the links below for two detailed tutorials on 
publishing images to the Web with Corel PHOTO-PAINT for Linux:
                
-Deciding on a File Format and Exporting for the Web:
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0EPLInkHiopJlU
 
-Creating an Image Map for Use as a Web Navigation Tool:
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0EPLInkHiopJlV

-----------------------------------------------------------------------
10. Migrating Your Windows Settings Over to Linux with Corel SmartMove
-----------------------------------------------------------------------
The leap to Linux is now easier than ever, but nobody wants to go through the 
tedious process of restoring every bookmark, e-mail preference and desktop option 
that they have set over the years. For this reason, Corel LINUX OS Second Edition 
was released with Corel SmartMove, an incredibly easy-to-use utility for 
transferring Windows-based application settings over to the Linux platform. To read 
a tutorial on how Corel SmartMove can help you get down to work quickly in your 
new Linux environment, visit 
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0EltHkmthOL

-------------------------------------------------
11. Optimizing Hard Disk Performance Using hdparm
-------------------------------------------------
hdparm is a little known yet very useful utility for tuning the performance of 
hard disk drives under Linux. The default driver settings used by the kernel tend 
to be conservative to ensure compatibility with most hardware. But newer hard 
drives have capabilities which, when enabled, can boost performance 
significantly. 

Some of the more useful hdparm options for boosting performance are summarized 
below: 

-c : Enables EIDE 32-bit i/o support between the PCI or VLB bus to the interface 
card

-m : Sets sector count for multiple sector I/O on the drive. Multiple sector 
mode (aka IDE Block Mode) is a feature of most modern IDE hard drives, permitting 
the transfer of multiple sectors per I/O interrupt rather than the usual one 
sector per interrupt. The hdparm -i option can be used to identify which sector 
count modes your drive supports. 

-u : Controls the interrupt unmask flag for the drive. A setting of 1 permits the 
driver to unmask other interrupts during the processing of a disk interrupt, 
greatly improving responsiveness and eliminating "serial port overrun" errors. 

-d : Controls the "using_dma" flag for this drive. This option only works with a 
few combinations of drives and interfaces which support DMA and which are known 
to the IDE driver. 

-S : Sets the standby (spindown) timeout for the drive. This value is used by 
the drive to determine how long to wait (with no disk activity) before turning 
off the spindle motor to save power. This doesn't boost performance, but can 
extend battery life on laptop systems. 

Experiment with your hardware settings to determine which options give optimal 
performance. To facilitate this, the -t option will perform a device read benchmark 
and provide timing results. For accurate results, run the measurements several 
times on an otherwise idle system. 

Before using the hdparm command, it is important to note the following advice from 
the hdparm man page: 

"Some of the hdparm options can cause file system corruption. As noted above, the 
-m sector count and -u 1 options should be used with caution at first, preferably on 
a read-only filesystem. Most drives work well with these features, but a few 
drive/controller combinations are not 100% compatible. Filesystem corruption may 
result. Backup everything before experimenting!" 

Here's an example that yielded roughly twice the throughput when certain options were 
changed on a laptop machine: 

********************************************************************
# hdparm -t /dev/hda 

/dev/hda: 
 Timing buffered disk reads:  64 MB in 14.79 seconds =  4.33 MB/sec 

# hdparm -q -c 1 -m 16 -u 1 /dev/hda 
 setting multcount to 16 
 setting unmaskirq to 1 (on) 
 multcount    = 16 (on) 
 unmaskirq    =  1 (on) 

# hdparm -t /dev/hda 

/dev/hda: 
 Timing buffered disk reads:  64 MB in  7.54 seconds =  8.49 MB/sec 
********************************************************************

Once you determine the optimal settings for your system, simply type the appropriate 
hdparm command in one of your system startup scripts so it will run every time the 
system starts up. 

======================
Developer's Corner
======================
-------------------------------------------------
12. Cprof: A Multi-Threaded Performance Profiler
-------------------------------------------------
For the uninitiated, a performance profiler is a tool that developers use to 
optimize software by identifying how much time is spent on different routines. The 
developer can then identify performance bottlenecks and modify the code to improve 
execution times.

The standard profiling tool for Linux is gprof, a very capable tool based on the 
original UNIX prof program. However, Corel's developers found existing Open Source 
community tools to have limited ability in the area of multi-threaded profiler 
support. To remedy this, Corel's Wine team developed a new tool for optimizing Wine 
and for supporting multiple-threaded programs. The result is "cprof" -- a tool that 
is applicable to any compiled program running under Linux and freely distributable 
under the GNU General Public License.

For more information, and to download the cprof source code and binary packages, 
visit Corel's Open Source Development Community site at 
http://ri-r1.corel.com/servlet/click?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHkE0EJikhM

====================================================================================
We Want to Hear From You!
We're always looking for ways to improve the newsletter, so your feedback is very 
important to us. If you have comments or suggestions on how we can tailor The Cube 
to better suit your needs, send your ideas along to [EMAIL PROTECTED]

Please note that technical support queries will not be dealt with through the above 
e-mail address. If you have a technical support question, please visit 
http://linux.corel.com/support.
Likewise, if you'd like to submit general feedback about any of our Linux products, 
please feel free to send an e-mail to [EMAIL PROTECTED]
====================================================================================
--------------------------------------------------------------------------------------------------------
At Corel, we respect your privacy. For information on our privacy policies, please 
visit
http://www.corel.com/legal/privacy.htm or contact us at: Customer Service, Corel
Corporation, 1600 Carling Avenue, Ottawa, Ontario, Canada, K1Z 8R7, Attention: Privacy.
Tel.: 1-613-728-8200 Fax: 1-613-761-9176. 

Please note that by indicating that you "prefer not to receive future e-mail from Corel
Campaigns" below, you will not receive e-mail or other notices regarding Corel's 
technical
support for your product, special offers, product upgrades or other updates. 
--------------------------------------------------------------------------------------------------------

______________________________________________________________________
This message was sent by Corel Campaigns using Responsys Interact.

If you prefer not to receive future e-mail from Corel Campaigns:
    http://ri-r1.corel.com/servlet/optout?9hkLsDVUEoJHlmLFMJLpHDNgkDLKNDHk

To view our permission marketing policy:
    http://www.rsvp0.net




Responder a